summaryrefslogtreecommitdiffstats
path: root/cypress_test/integration_tests/desktop/calc
diff options
context:
space:
mode:
authorGökay Şatır <gokaysatir@gmail.com>2023-05-09 16:11:49 +0300
committerGökay ŞATIR <gokaysatir@gmail.com>2023-05-10 08:59:00 +0300
commitbd4fda889555f68a8c20b460920ff3ee9c98e36f (patch)
tree5f58ee18cfdbd6719ef1a21ee99fdff56de506b8 /cypress_test/integration_tests/desktop/calc
parentRevert "Dark Mode add color-scheme: dark setting" (diff)
downloadonline-bd4fda889555f68a8c20b460920ff3ee9c98e36f.tar.gz
online-bd4fda889555f68a8c20b460920ff3ee9c98e36f.zip
Enable one more desktop calc test.
Signed-off-by: Gökay Şatır <gokaysatir@gmail.com> Change-Id: I754c98f91aa5a8a4791e017e59432c08759b2355
Diffstat (limited to 'cypress_test/integration_tests/desktop/calc')
-rw-r--r--cypress_test/integration_tests/desktop/calc/delete_objects_spec.js28
1 files changed, 8 insertions, 20 deletions
diff --git a/cypress_test/integration_tests/desktop/calc/delete_objects_spec.js b/cypress_test/integration_tests/desktop/calc/delete_objects_spec.js
index 39806b01f1..3930fe232c 100644
--- a/cypress_test/integration_tests/desktop/calc/delete_objects_spec.js
+++ b/cypress_test/integration_tests/desktop/calc/delete_objects_spec.js
@@ -1,7 +1,6 @@
/* global describe it cy require afterEach beforeEach */
var helper = require('../../common/helper');
-
describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Delete Objects', function() {
var origTestFileName = 'delete_objects.ods';
var testFileName;
@@ -27,10 +26,8 @@ describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Delete Objects', function(
it('Delete Shapes', function() {
cy.cGet('#toolbar-up > .w2ui-scroll-right').click();
- cy.cGet('#tb_editbar_item_insertshapes')
- .click()
- .cGet('.col.w2ui-icon.symbolshapes')
- .click();
+ cy.cGet('#tb_editbar_item_insertshapes').click();
+ cy.cGet('.col.w2ui-icon.symbolshapes').should($el => { expect(Cypress.dom.isDetached($el)).to.eq(false); }).click();
cy.cGet('.leaflet-control-buttons-disabled path.leaflet-interactive')
.should('exist');
@@ -42,23 +39,14 @@ describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Delete Objects', function(
.should('not.exist');
});
- it.skip('Delete Chart' , function() {
+ it('Delete Chart' , function() {
cy.cGet('#toolbar-up > .w2ui-scroll-right').click();
//insert
- cy.cGet('#tb_editbar_item_insertobjectchart')
- .click();
-
- helper.clickOnIdle('.ui-pushbutton.jsdialog.button-primary');
-
- cy.cGet('.leaflet-control-buttons-disabled path.leaflet-interactive')
- .should('exist');
-
+ cy.cGet('#tb_editbar_item_insertobjectchart').click();
+ cy.cGet('.ui-pushbutton.jsdialog.button-primary').should($el => { expect(Cypress.dom.isDetached($el)).to.eq(false); }).click();
+ cy.cGet('.leaflet-control-buttons-disabled path.leaflet-interactive').should('exist');
//delete
helper.typeIntoDocument('{del}');
-
- cy.wait(2000);
-
- cy.cGet('.leaflet-control-buttons-disabled path.leaflet-interactive')
- .should('not.exist');
+ cy.cGet('.leaflet-control-buttons-disabled path.leaflet-interactive').should('not.exist');
});
});
@@ -1,7 +1,6 @@
-/* global describe it cy require afterEach beforeEach */
+/* global describe it cy require afterEach beforeEach expect Cypress*/
var helper = require('../../common/helper');